@@ -1,7 +1,10 @@
 #include "artists.h"
 #include "xbmcconnection.h"
-
+#include "xbmc.h"
 #include "albums.h"
+#include "audioplaylistitem.h"
+#include "audioplayer.h"
+#include "playlist.h"
 
 Artists::Artists(XbmcModel *parent) :
     XbmcModel(parent)
@@ -28,7 +31,7 @@ void Artists::responseReceived(int id, const QVariantMap &rsp)
         QStandardItem *item = new QStandardItem();
         item->setText(itemMap.value("label").toString());
         item->setData("directory", Qt::UserRole);
-        item->setData(itemMap.value("artistid").toInt(), Qt::UserRole + 100);
+        item->setData(itemMap.value("artistid").toInt(), RoleArtistId);
         list.append(item);
     }
     beginInsertRows(QModelIndex(), 0, list.count() - 1);
@@ -47,23 +50,35 @@ QVariant Artists::data(const QModelIndex &index, int role) const
     switch(role) {
     case Qt::DisplayRole:
         return m_list.at(index.row())->text();
-    case Qt::UserRole+1:
+    case RoleFileType:
         return "directory";
-    case Qt::UserRole+2:
+    case RoleSubtitle:
         return "";
+    case RolePlayable:
+        return true;
     }
     return QVariant();
 }
 
 XbmcModel *Artists::enterItem(int index)
 {
-    return new Albums(m_list.at(index)->data(Qt::UserRole + 100).toInt(), this);
+    return new Albums(m_list.at(index)->data(RoleArtistId).toInt(), this);
 }
 
 void Artists::playItem(int index)
 {
-    Q_UNUSED(index)
-    qDebug() << "Artists::play() not implemented yet";
+    AudioPlaylistItem pItem;
+    pItem.setArtistId(m_list.at(index)->data(RoleArtistId).toInt());
+    Xbmc::instance()->audioPlayer()->playlist()->clear();
+    Xbmc::instance()->audioPlayer()->playlist()->addItems(pItem);
+    Xbmc::instance()->audioPlayer()->playlist()->playItem(0);
+}
+
+void Artists::addToPlaylist(int index)
+{
+    AudioPlaylistItem pItem;
+    pItem.setArtistId(m_list.at(index)->data(RoleArtistId).toInt());
+    Xbmc::instance()->audioPlayer()->playlist()->addItems(pItem);
 }
 
 QString Artists::title() const
