@@ -16,9 +16,13 @@ public:
 
     XbmcModel *enterItem(int index);
     void playItem(int index);
+    void addToPlaylist(int index);
 
     QString title() const;
 
+public slots:
+    void scanForContent();
+
 private:
     enum Request {
         RequestArtists,
@@ -26,8 +30,6 @@ private:
     };
     QMap<int, Request> m_requestMap;
 
-    QStringList m_itemlist;
-
 };
 
 #endif // AUDIOLIBRARY_H
