@@ -7,6 +7,8 @@
 
 Episodes::Episodes(int tvshowid, int seasonid, const QString &seasonString, XbmcModel *parent):
     XbmcModel(parent),
+    m_tvshowid(tvshowid),
+    m_seasonid(seasonid),
     m_seasonString(seasonString)
 {
     QVariantMap params;
@@ -44,8 +46,8 @@ void Episodes::responseReceived(int id, const QVariantMap &rsp)
         QStandardItem *item = new QStandardItem();
         item->setText(itemMap.value("label").toString());
 //        item->setData(itemMap.value("showtitle").toString() + " - " + itemMap.value("season").toString(), Qt::UserRole+2);
-        item->setData(itemMap.value("showtitle").toString() + " - " + m_seasonString, Qt::UserRole+2);
-        item->setData(itemMap.value("episodeid").toInt(), Qt::UserRole + 100);
+        item->setData(itemMap.value("showtitle").toString() + " - " + m_seasonString, RoleSubtitle);
+        item->setData(itemMap.value("episodeid").toInt(), RoleEpisodeId);
         list.append(item);
     }
     beginInsertRows(QModelIndex(), 0, list.count() - 1);
@@ -62,8 +64,10 @@ int Episodes::rowCount(const QModelIndex &parent) const
 QVariant Episodes::data(const QModelIndex &index, int role) const
 {
     switch(role) {
-    case Qt::UserRole+1:
+    case RoleFileType:
         return "file";
+    case RolePlayable:
+        return true;
     }
     return m_list.at(index.row())->data(role);
 }
@@ -77,14 +81,22 @@ XbmcModel *Episodes::enterItem(int index)
 
 void Episodes::playItem(int index)
 {
-    qDebug() << "should play item" << index << "episodeid is" << m_list.at(index)->data(Qt::UserRole+100).toInt();
     Xbmc::instance()->videoPlayer()->playlist()->clear();
     VideoPlaylistItem item;
-    item.setEpisodeId(m_list.at(index)->data(Qt::UserRole+100).toInt());
+    item.setEpisodeId(m_list.at(index)->data(RoleEpisodeId).toInt());
     Xbmc::instance()->videoPlayer()->playlist()->addItems(item);
     Xbmc::instance()->videoPlayer()->playlist()->playItem(0);
 }
 
+void Episodes::addToPlaylist(int row)
+{
+    VideoPlaylistItem pItem;
+    pItem.setTvShowId(m_tvshowid);
+    pItem.setSeasonId(m_seasonid);
+    pItem.setEpisodeId(index(row, 0, QModelIndex()).data(RoleEpisodeId).toInt());
+    Xbmc::instance()->videoPlayer()->playlist()->addItems(pItem);
+}
+
 QString Episodes::title() const
 {
     return "Episodes";
