@@ -16,9 +16,13 @@ public:
 
     XbmcModel *enterItem(int index);
     void playItem(int index);
+    void addToPlaylist(int index);
 
     QString title() const;
 
+public slots:
+    void scanForContent();
+
 private:
     enum Request {
         RequestArtists,
