@@ -8,9 +8,10 @@ XbmcModel::XbmcModel(XbmcModel *parent) :
 {
     QHash<int, QByteArray> roleNames;
     roleNames.insert(Qt::DisplayRole, "title");
-    roleNames.insert(Qt::UserRole+1, "filetype");
-    roleNames.insert(Qt::UserRole+2, "subtitle");
-    roleNames.insert(Qt::UserRole+3, "duration");
+    roleNames.insert(RoleFileType, "filetype");
+    roleNames.insert(RoleSubtitle, "subtitle");
+    roleNames.insert(RoleDuration, "duration");
+    roleNames.insert(RolePlayable, "playable");
     setRoleNames(roleNames);
 }
 
@@ -49,3 +50,19 @@ QModelIndex XbmcModel::parent(const QModelIndex &child) const
     Q_UNUSED(child)
     return QModelIndex();
 }
+
+int XbmcModel::findItem(const QString &string, bool caseSensitive)
+{
+    foreach(QStandardItem* item, m_list) {
+        if(caseSensitive) {
+            if(item->data(Qt::DisplayRole).toString().startsWith(string)) {
+                return m_list.indexOf(item);
+            }
+        } else {
+            if(item->data(Qt::DisplayRole).toString().toLower().startsWith(string.toLower())) {
+                return m_list.indexOf(item);
+            }
+        }
+    }
+    return -1;
+}
